Summary: The Cistron RADIUS daemon (with PAM).
Name: radiusd-cistron
Version: 1.6.6
Release: 2
Source: radiusd-cistron-%{version}.tar.gz
Patch0: radiusd-cistron-1.6.4-system-auth.patch
Patch1: radiusd-cistron-1.6.6-init.patch
Patch2: radiusd-1.6.6-pamdir.patch
URL: http://www.radius.cistron.nl/
License: GPL
Group: System Environment/Daemons
BuildRoot: %{_tmppath}/%{name}-root
Requires: /etc/pam.d/system-auth
PreReq: /sbin/ldconfig , /sbin/service 

%description
The radiusd-cistron package contains a server daemon for the Remote
Authentication Dial-In User Server (RADIUS) client/server security
protocol. A RADIUS system works by storing security information in a
central location (the RADIUS server). RADIUS clients like Portslave
(included in the portslave-cistron package) communicate with the
server to authenticate users.

This RADIUS daemon supports access based on huntgroups; multiple
DEFAULT entries in users' files; all users' file entries can
optionally fall through; caching all config files in memory; keeping a
list of logged in users in the radutmp file; the radwho program can be
installed as fingerd; logging both UNIX WTMP file format and RADIUS
detail logfiles; and the Simultaneous-Use=X parameter (so you can
prevent double logins).

Note that if you install radiusd-cistron, you'll need to install
portslave-cistron on client machines.

%prep 
%setup -q
%patch0 -p1 -b .system-auth
%patch1 -p1 -b .init
%patch2 -p1 -b .pamdir

cd raddb
for f in clients users naslist huntgroups ; do cp $f $f-dist ; done
cd ..

%build
cd src
make PAM=-DPAM PAMLIB="-lpam -ldl" CFLAGS="-Wall ${RPM_OPT_FLAGS}"
cd ..

%install
# prepare $RPM_BUILD_ROOT
rm -rf $RPM_BUILD_ROOT

#remove the CVS cruft so we don't try to install it
rm -rf `find . -name CVS -type d`

mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d \
	$RPM_BUILD_ROOT/etc/pam.d \
	$RPM_BUILD_ROOT/etc/raddb \
	$RPM_BUILD_ROOT/etc/logrotate.d \
	$RPM_BUILD_ROOT%{_sbindir} \
	$RPM_BUILD_ROOT%{_bindir} \
	$RPM_BUILD_ROOT%{_datadir} \
	$RPM_BUILD_ROOT%{_mandir}/man{1,5,8} \
	$RPM_BUILD_ROOT/var/log \
	$RPM_BUILD_ROOT/var/radacct

# make install
cd src
make install BINDIR=${RPM_BUILD_ROOT}%{_bindir} SBINDIR=${RPM_BUILD_ROOT}%{_sbindir} \
	MANDIR=$RPM_BUILD_ROOT%{_mandir} RADIUS_DIR=$RPM_BUILD_ROOT/etc/raddb PAMDIR=$RPM_BUILD_ROOT/etc/pam.d
install -m 755 radtest ${RPM_BUILD_ROOT}%{_bindir}
cd ..

# do /etc/raddb
cd raddb
install -m 640 * ${RPM_BUILD_ROOT}/etc/raddb
cd ..

# radwatch
install -m 755 scripts/radwatch ${RPM_BUILD_ROOT}%{_sbindir}/

# other files
cd redhat
install -m 555 rc.radiusd-redhat ${RPM_BUILD_ROOT}/etc/rc.d/init.d/radiusd
install -m 644 radiusd-logrotate ${RPM_BUILD_ROOT}/etc/logrotate.d/radiusd
cd ..

# man pages
cd doc
for i in 1 8; do
	install -m 444 *.$i ${RPM_BUILD_ROOT}%{_mandir}/man$i
done
install -m 444 clients.5rad ${RPM_BUILD_ROOT}%{_mandir}/man5/
install -m 444 naslist.5rad ${RPM_BUILD_ROOT}%{_mandir}/man5/
cd ..

for i in radutmp radwtmp radius.log; do
	touch ${RPM_BUILD_ROOT}/var/log/$i
done
mkdir -p ${RPM_BUILD_ROOT}/var/log/radacct

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/chkconfig --add radiusd

%preun
if [ "$1" = "0" ]; then
	/sbin/service radiusd stop > /dev/null 2>&1
	/sbin/chkconfig --del radiusd
fi

%postun
if [ "$1" -ge "1" ]; then
	/sbin/service radiusd condrestart > /dev/null 2>&1
fi

%files
%defattr(-,root,root)
%doc doc/ChangeLog doc/README doc/README.pam doc/README.proxy 
%doc doc/README.usersfile doc/README.simul doc/INSTALL.OLD 
%doc doc/Makefile.README doc/README.cisco todo/ 
%doc COPYRIGHT.Cistron COPYRIGHT.Livingston

%{_bindir}/*
%{_sbindir}/*
%{_mandir}/*/*
/var/log/radutmp
/var/log/radwtmp
/var/log/radius.log
%dir /var/log/radacct/

%dir /etc/raddb/
%config /etc/raddb/*
%config /etc/pam.d/radius
%config /etc/logrotate.d/radiusd
%config /etc/rc.d/init.d/radiusd

%changelog
* Wed Feb 20 2002 Bernhard Rosenkraenzer <bero@redhat.com> 1.6.6-1
- Update to 1.6.6, fixing security problems
- Fix build as non-root

* Wed Apr 25 2001 Tim Powers <timp@redhat.com>
- fixed the preun and initscripts for real this time :)

* Tue Apr 24 2001 Tim Powers <timp@redhat.com>
- merged patch for initscript submitted by shishz@alum.rpi.edu (bug
#37473, fixes problems with stopping radiusd)

* Tue Jan 23 2001 Tim Powers <timp@redhat.com>
- updated initscript

* Mon Nov 20 2000 Tim Powers <timp@redhat.com>
- rebuilt to fix bad dir perms

* Tue Nov 14 2000 Tim Powers <timp@redhat.com>
- updated to 1.6.4

* Fri Jul 28 2000 Than Ngo <than@redhat.de>
- add missing restart function in startup script
- cleanup specfile, use %%{_mandir} instead hardcode

* Fri Jul 28 2000 Tim Powers <timp@redhat.com>
- fixed condrestart so that it doesn't return 1 if the test fails

* Mon Jul 24 2000 Prospector <prospector@redhat.com>
- rebuilt

* Mon Jul 17 2000 Tim Powers <timp@redhat.com>
- inits in rc.d/init.d again. Using /sbin/service to start/stop inits

* Mon Jul 10 2000 Tim Powers <timp@redhat.com>
- rebuilt

* Thu Jul 06 2000 Tim Powers <timp@redhat.com>
- fixed PreReq to PreReq /etc/init.d

* Tue Jun 27 2000 Tim Powers <timp@redhat.com>
- make sure that we are using chkconfig instead of creating manula link junk
- cleaned up init file, added condrestart
- added Prereq's
- added post, preun, postun sections

* Thu Jun  1 2000 Nalin Dahyabhai <nalin@redhat.com>
- modify PAM setup to use system-auth

* Thu May 18 2000 Tim Powers <timp@redhat.com>
- update to 1.6.3
- put man pages in /usr/share/man

* Mon Nov 29 1999 Tim Powers <timp@redhat.com>
- updated to 1.6.1

* Mon Aug 9 1999 Tim Powers <timp@redhat.com>
- using this since the origional RPM I created placed a cronjob that was doing
  the wrong thing. This places some stuff in /etc/logrotate.d like it should.
- added %defattr in %files section
- changed group
- built for Powertools

* Sat Nov 21 1998 Tim Hockin <thockin@ais.net>
- Based on work by Christopher McCrory <chrismcc@netus.com>
- Build with PAM
- Included pam.d/radius
- Fixed some small errors in this spec
- Changed to build to BuildRoot
- Changed Release to "beta11" from "1"
- Included users, naslist, huntgroups, clients files, not just -dist

* Tue Oct 27 1998 Mauricio Mello de Andrade <mandrade@mma.com.br>
- Corrected the script to Start/Stop the Radius under RH5.x
- Included the script to Rotate Radius Logs under RedHat
- Checkrad Utility now works fine with Cyclades PathRas
